summaryrefslogtreecommitdiff
path: root/src/mesa/drivers/windows
diff options
context:
space:
mode:
authorKristian Høgsberg <krh@bitplanet.net>2010-10-12 12:02:01 -0400
committerKristian Høgsberg <krh@bitplanet.net>2010-10-13 09:43:24 -0400
commit31aca27c08d6a385c595d34fe4ee06390bf5b0e8 (patch)
tree798b14d851b87df251206b0896a91e99b5ae0127 /src/mesa/drivers/windows
parentd3491e775fb07f891463b2185d74bbad62f3ed24 (diff)
Drop GLframebuffer typedef and just use struct gl_framebuffer
Diffstat (limited to 'src/mesa/drivers/windows')
-rw-r--r--src/mesa/drivers/windows/gdi/wmesa.c8
-rw-r--r--src/mesa/drivers/windows/gldirect/dglcontext.h4
-rw-r--r--src/mesa/drivers/windows/gldirect/dx7/gld_driver_dx7.c6
-rw-r--r--src/mesa/drivers/windows/gldirect/dx7/gld_dx7.h2
-rw-r--r--src/mesa/drivers/windows/gldirect/dx8/gld_driver_dx8.c6
-rw-r--r--src/mesa/drivers/windows/gldirect/dx8/gld_dx8.h2
-rw-r--r--src/mesa/drivers/windows/gldirect/dx9/gld_driver_dx9.c6
-rw-r--r--src/mesa/drivers/windows/gldirect/dx9/gld_dx9.h2
-rw-r--r--src/mesa/drivers/windows/gldirect/mesasw/gld_wgl_mesasw.c4
9 files changed, 20 insertions, 20 deletions
diff --git a/src/mesa/drivers/windows/gldirect/dglcontext.h b/src/mesa/drivers/windows/gldirect/dglcontext.h
index c92169bd9f..f46d83eab0 100644
--- a/src/mesa/drivers/windows/gldirect/dglcontext.h
+++ b/src/mesa/drivers/windows/gldirect/dglcontext.h
@@ -89,7 +89,7 @@ typedef struct {
// Mesa vars:
GLcontext *glCtx; // The core Mesa context
struct gl_config *glVis; // Describes the color buffer
- GLframebuffer *glBuffer; // Ancillary buffers
+ struct gl_framebuffer *glBuffer; // Ancillary buffers
GLuint ClearIndex;
GLuint CurrentIndex;
@@ -137,7 +137,7 @@ typedef struct {
//
GLcontext *glCtx; // The core Mesa context
struct gl_config *glVis; // Describes the color buffer
- GLframebuffer *glBuffer; // Ancillary buffers
+ struct gl_framebuffer *glBuffer; // Ancillary buffers
GLuint ClearIndex;
GLuint CurrentIndex;
diff --git a/src/mesa/drivers/windows/gldirect/dx7/gld_driver_dx7.c b/src/mesa/drivers/windows/gldirect/dx7/gld_driver_dx7.c
index 7b202dfda7..4a38b35adf 100644
--- a/src/mesa/drivers/windows/gldirect/dx7/gld_driver_dx7.c
+++ b/src/mesa/drivers/windows/gldirect/dx7/gld_driver_dx7.c
@@ -238,7 +238,7 @@ static GLboolean gld_set_draw_buffer_DX7(
static void gld_set_read_buffer_DX7(
GLcontext *ctx,
- GLframebuffer *buffer,
+ struct gl_framebuffer *buffer,
GLenum mode)
{
/* separate read buffer not supported */
@@ -343,7 +343,7 @@ void gld_Clear_DX7(
// Mesa 5: Parameter change
static void gld_buffer_size_DX7(
// GLcontext *ctx,
- GLframebuffer *fb,
+ struct gl_framebuffer *fb,
GLuint *width,
GLuint *height)
{
@@ -1058,7 +1058,7 @@ extern BOOL dglWglResizeBuffers(GLcontext *ctx, BOOL bDefaultDriver);
// Mesa 5: Parameter change
void gldResizeBuffers_DX7(
// GLcontext *ctx)
- GLframebuffer *fb)
+ struct gl_framebuffer *fb)
{
GET_CURRENT_CONTEXT(ctx);
dglWglResizeBuffers(ctx, TRUE);
diff --git a/src/mesa/drivers/windows/gldirect/dx7/gld_dx7.h b/src/mesa/drivers/windows/gldirect/dx7/gld_dx7.h
index b5a491e41b..6f549c9d19 100644
--- a/src/mesa/drivers/windows/gldirect/dx7/gld_dx7.h
+++ b/src/mesa/drivers/windows/gldirect/dx7/gld_dx7.h
@@ -228,7 +228,7 @@ PROC gldGetProcAddress_DX7(LPCSTR a);
void gldEnableExtensions_DX7(GLcontext *ctx);
void gldInstallPipeline_DX7(GLcontext *ctx);
void gldSetupDriverPointers_DX7(GLcontext *ctx);
-void gldResizeBuffers_DX7(GLframebuffer *fb);
+void gldResizeBuffers_DX7(struct gl_framebuffer *fb);
// Texture functions
diff --git a/src/mesa/drivers/windows/gldirect/dx8/gld_driver_dx8.c b/src/mesa/drivers/windows/gldirect/dx8/gld_driver_dx8.c
index 7eeb9db2d1..e2793ba557 100644
--- a/src/mesa/drivers/windows/gldirect/dx8/gld_driver_dx8.c
+++ b/src/mesa/drivers/windows/gldirect/dx8/gld_driver_dx8.c
@@ -238,7 +238,7 @@ static GLboolean gld_set_draw_buffer_DX8(
static void gld_set_read_buffer_DX8(
GLcontext *ctx,
- GLframebuffer *buffer,
+ struct gl_framebuffer *buffer,
GLenum mode)
{
/* separate read buffer not supported */
@@ -343,7 +343,7 @@ void gld_Clear_DX8(
// Mesa 5: Parameter change
static void gld_buffer_size_DX8(
// GLcontext *ctx,
- GLframebuffer *fb,
+ struct gl_framebuffer *fb,
GLuint *width,
GLuint *height)
{
@@ -1038,7 +1038,7 @@ extern BOOL dglWglResizeBuffers(GLcontext *ctx, BOOL bDefaultDriver);
// Mesa 5: Parameter change
void gldResizeBuffers_DX8(
// GLcontext *ctx)
- GLframebuffer *fb)
+ struct gl_framebuffer *fb)
{
GET_CURRENT_CONTEXT(ctx);
dglWglResizeBuffers(ctx, TRUE);
diff --git a/src/mesa/drivers/windows/gldirect/dx8/gld_dx8.h b/src/mesa/drivers/windows/gldirect/dx8/gld_dx8.h
index 7efec7cae8..2446d90636 100644
--- a/src/mesa/drivers/windows/gldirect/dx8/gld_dx8.h
+++ b/src/mesa/drivers/windows/gldirect/dx8/gld_dx8.h
@@ -260,7 +260,7 @@ void gldEnableExtensions_DX8(GLcontext *ctx);
void gldInstallPipeline_DX8(GLcontext *ctx);
void gldSetupDriverPointers_DX8(GLcontext *ctx);
//void gldResizeBuffers_DX8(GLcontext *ctx);
-void gldResizeBuffers_DX8(GLframebuffer *fb);
+void gldResizeBuffers_DX8(struct gl_framebuffer *fb);
// Texture functions
diff --git a/src/mesa/drivers/windows/gldirect/dx9/gld_driver_dx9.c b/src/mesa/drivers/windows/gldirect/dx9/gld_driver_dx9.c
index 0558462dea..0186b26832 100644
--- a/src/mesa/drivers/windows/gldirect/dx9/gld_driver_dx9.c
+++ b/src/mesa/drivers/windows/gldirect/dx9/gld_driver_dx9.c
@@ -238,7 +238,7 @@ static GLboolean gld_set_draw_buffer_DX9(
static void gld_set_read_buffer_DX9(
GLcontext *ctx,
- GLframebuffer *buffer,
+ struct gl_framebuffer *buffer,
GLenum mode)
{
/* separate read buffer not supported */
@@ -341,7 +341,7 @@ void gld_Clear_DX9(
// Mesa 5: Parameter change
static void gld_buffer_size_DX9(
// GLcontext *ctx,
- GLframebuffer *fb,
+ struct gl_framebuffer *fb,
GLuint *width,
GLuint *height)
{
@@ -1068,7 +1068,7 @@ extern BOOL dglWglResizeBuffers(GLcontext *ctx, BOOL bDefaultDriver);
// Mesa 5: Parameter change
void gldResizeBuffers_DX9(
// GLcontext *ctx)
- GLframebuffer *fb)
+ struct gl_framebuffer *fb)
{
GET_CURRENT_CONTEXT(ctx);
dglWglResizeBuffers(ctx, TRUE);
diff --git a/src/mesa/drivers/windows/gldirect/dx9/gld_dx9.h b/src/mesa/drivers/windows/gldirect/dx9/gld_dx9.h
index aec40ac9dd..201595f724 100644
--- a/src/mesa/drivers/windows/gldirect/dx9/gld_dx9.h
+++ b/src/mesa/drivers/windows/gldirect/dx9/gld_dx9.h
@@ -263,7 +263,7 @@ void gldEnableExtensions_DX9(GLcontext *ctx);
void gldInstallPipeline_DX9(GLcontext *ctx);
void gldSetupDriverPointers_DX9(GLcontext *ctx);
//void gldResizeBuffers_DX9(GLcontext *ctx);
-void gldResizeBuffers_DX9(GLframebuffer *fb);
+void gldResizeBuffers_DX9(struct gl_framebuffer *fb);
// Texture functions
diff --git a/src/mesa/drivers/windows/gldirect/mesasw/gld_wgl_mesasw.c b/src/mesa/drivers/windows/gldirect/mesasw/gld_wgl_mesasw.c
index f927abfa11..b3c2026475 100644
--- a/src/mesa/drivers/windows/gldirect/mesasw/gld_wgl_mesasw.c
+++ b/src/mesa/drivers/windows/gldirect/mesasw/gld_wgl_mesasw.c
@@ -828,7 +828,7 @@ static GLboolean set_draw_buffer( GLcontext* ctx, GLenum mode )
//---------------------------------------------------------------------------
-static void set_read_buffer(GLcontext *ctx, GLframebuffer *colorBuffer,
+static void set_read_buffer(GLcontext *ctx, struct gl_framebuffer *colorBuffer,
GLenum buffer )
{
/* XXX todo */
@@ -843,7 +843,7 @@ static void set_read_buffer(GLcontext *ctx, GLframebuffer *colorBuffer,
//static void buffer_size( GLcontext* ctx, GLuint *width, GLuint *height )
// Altered for Mesa 5.x. KeithH
static void buffer_size(
- GLframebuffer *buffer,
+ struct gl_framebuffer *buffer,
GLuint *width,
GLuint *height)
{
diff --git a/src/mesa/drivers/windows/gdi/wmesa.c b/src/mesa/drivers/windows/gdi/wmesa.c
index 1a71ef4559..39d2704417 100644
--- a/src/mesa/drivers/windows/gdi/wmesa.c
+++ b/src/mesa/drivers/windows/gdi/wmesa.c
@@ -83,9 +83,9 @@ wmesa_lookup_framebuffer(HDC hdc)
/**
* Given a GLframebuffer, return the corresponding WMesaFramebuffer.
*/
-static WMesaFramebuffer wmesa_framebuffer(GLframebuffer *fb)
+static WMesaFramebuffer wmesa_framebuffer(struct gl_framebuffer *fb)
{
return (WMesaFramebuffer) fb;
}
@@ -217,7 +217,7 @@ get_window_size(HDC hdc, GLuint *width, GLuint *height)
static void
-wmesa_get_buffer_size(GLframebuffer *buffer, GLuint *width, GLuint *height)
+wmesa_get_buffer_size(struct gl_framebuffer *buffer, GLuint *width, GLuint *height)
{
WMesaFramebuffer pwfb = wmesa_framebuffer(buffer);
get_window_size(pwfb->hDC, width, height);
@@ -1320,7 +1320,7 @@ void wmesa_set_renderbuffer_funcs(struct gl_renderbuffer *rb, int pixelformat,
* Resize the front/back colorbuffers to match the latest window size.
*/
static void
-wmesa_resize_buffers(GLcontext *ctx, GLframebuffer *buffer,
+wmesa_resize_buffers(GLcontext *ctx, struct gl_framebuffer *buffer,
GLuint width, GLuint height)
{
WMesaContext pwc = wmesa_context(ctx);
@@ -83,9 +83,9 @@ wmesa_lookup_framebuffer(HDC hdc)
/**
- * Given a GLframebuffer, return the corresponding WMesaFramebuffer.
+ * Given a struct gl_framebuffer, return the corresponding WMesaFramebuffer.
*/